@@ -6,8 +6,8 @@ from types import ModuleType
 
 # __all__ is computed below.
 __pre_all__ = ["QtCore", "QtGui", "QtWidgets", "QtPrintSupport", "QtSql", "QtNetwork", "QtTest", "QtConcurrent", "QtDBus", "QtDesigner", "QtXml", "QtHelp", "QtMultimedia", "QtMultimediaWidgets", "QtOpenGL", "QtOpenGLWidgets", "QtPdf", "QtPdfWidgets", "QtPositioning", "QtLocation", "QtNetworkAuth", "QtNfc", "QtQml", "QtQuick", "QtQuick3D", "QtQuickControls2", "QtQuickTest", "QtQuickWidgets", "QtRemoteObjects", "QtScxml", "QtSensors", "QtSerialPort", "QtSerialBus", "QtStateMachine", "QtTextToSpeech", "QtCharts", "QtSpatialAudio", "QtSvg", "QtSvgWidgets", "QtDataVisualization", "QtGraphs", "QtGraphsWidgets", "QtBluetooth", "QtUiTools", "QtWebChannel", "QtWebEngineCore", "QtWebEngineWidgets", "QtWebEngineQuick", "QtWebSockets", "QtHttpServer", "Qt3DCore", "Qt3DRender", "Qt3DInput", "Qt3DLogic", "Qt3DAnimation", "Qt3DExtras"]
-__version__ = "6.8.1.1"
-__version_info__ = (6, 8, 1.1, "", "")
+__version__ = "6.8.2"
+__version_info__ = (6, 8, 2, "", "")
 
 SKIP_MYPY_TEST = bool("")
 
@@ -55,7 +55,7 @@ def _setupQtDirectories():
 
     pyside_package_dir = Path(__file__).parent.resolve()
 
-    if sys.platform == 'win32' and sys.version_info[0] == 3 and sys.version_info[1] >= 8:
+    if sys.platform == 'win32':
         for dir in _additional_dll_directories(pyside_package_dir):
             os.add_dll_directory(os.fspath(dir))
 
